==> camel-karavan-4.1.0.zip: camel-karavan-4.1.0/karavan-web/karavan-app/src/main/webui/src/api/SsoApi.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import Keycloak from "keycloak-js";
import {KaravanApi} from "./KaravanApi";

export class SsoApi {

    static keycloak?: Keycloak;

    static auth(after: () => void) {
        KaravanApi.getConfig((config: any) => {
            SsoApi.keycloak = new Keycloak({url: config.url, realm: 'karavan', clientId: 'karavan-frontend'});
            SsoApi.keycloak.init({onLoad: 'login-required', flow: 'hybrid'}).then(value => {
                console.log('SsoApi', 'User is now authenticated.');
                KaravanApi.isAuthorized = true;
                after();
            }).catch(reason => {
                console.log('SsoApi', 'Error:', reason);
                window.location.reload();
            });
        });
    }
}

==> camel-karavan-4.3.0.zip: camel-karavan-4.3.0/karavan-web/karavan-app/src/main/webui/src/api/SsoApi.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import Keycloak from "keycloak-js";
import {KaravanApi} from "./KaravanApi";

export class SsoApi {

    static keycloak?: Keycloak;

    static auth(after: () => void) {
        KaravanApi.getConfig((config: any) => {
            SsoApi.keycloak = new Keycloak({url: config.url, realm: config.realm, clientId: config.clientId});
            SsoApi.keycloak.init({onLoad: 'login-required', flow: 'hybrid', checkLoginIframe: false}).then(value => {
                console.log('SsoApi', 'User is now authenticated.');
                KaravanApi.isAuthorized = true;
                after();
            }).catch(reason => {
                console.log('SsoApi', 'Error:', reason);
                window.location.reload();
            });
        });
    }
}
